<?php
namespace Aws\BedrockAgentRuntime\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Agents for Amazon Bedrock Runtime** service.
 */
class BedrockAgentRuntimeException extends AwsException {}
